==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Deepin pregledovalnik slik</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Pregledovalnik slik je orodje za prikazovanje slik z modernim vmesnikom in mehkim delovanjem.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Slike</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Podatki o sliki</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Osnovni podatki</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Ta datoteka vsebuje več strani, za ogled vseh strani uporabite Evince.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Odpri mapo</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nimate dovoljenja za ogled slike</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Slika ni bila najdena</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Ime</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Vrsta</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Datum spremembe</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Dimenzije</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Velikost datoteke</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Datum slikanja</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Način osvetlitve</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program osvetlitve</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Čas osvetlitve</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Zaslonka</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Goriščna razdalja</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Največja zaslonka</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Način meritve</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Temperatura beline</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Kompenzacija flasha</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model objektiva</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Barvni model</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model fotoaparata</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimenzije</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Oznaka</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Brez povečave</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Prilagodi stran sliki</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Prilagodi sliko strani</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Povečaj/pomanjšaj na:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>milimetrov</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>centimetrov</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>palcev</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Položaj slike</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Sprememba velikosti</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Nastavitve slike</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Nastavitve slike</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Senčila</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Menjalnik</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Drsenje</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Prstan</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>dd/MM/yyyy HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Potrdi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Vnesite novo ime</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Izberite mapo</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Sinhronizacija te mape je onemogočena</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Dodaj mapo</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Upravljanje sinhronizacijske mape</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Seznam map je prazen</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Prekliči sinhronizacijo</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Slike</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Naprava je bila odstranjena</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Mapa ne obstaja več</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Preračunavam...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Prikazovanje slik</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Prikaz</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Čez cel zaslon</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaprojekcija</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Končaj diaprojekcijo</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstrani iz albuma</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Dodaj med priljubljene</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odstrani iz priljubljenih</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zasukaj v desno</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zasukaj v levo</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavi za ozadje</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacije o sliki</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Predhodna</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Naslednja</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Predhodni zaslon</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Naslednji zaslon</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nov album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Prikaži bližnjice</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Izhod iz celozaslonskega načina</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Približaj</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Oddalji</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Odpri</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Vnesite novo bližnjico</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Bližnjice</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Prikaži sliko</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Ponastavi na privzeto</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Prikaz</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Čez cel zaslon</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaprojekcija</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Končaj diaprojekcijo</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tiskanje</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstrani iz albuma</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Dodaj med priljubljene</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odstrani iz priljubljenih</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zasukaj v desno</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zasukaj v levo</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavi za ozadje</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacije o sliki</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nov album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Prejšnja</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pavza</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Predvajaj</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Naslednja</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Izhod</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Nastavitve prosojnice</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Učinek menjavanja</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Čas prikaza</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Čas menjavanja</translation>
    </message>
    <message>
        <source>second</source>
        <translation>s</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>Moje priljubljene</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Prejšnja</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Naslednja</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Razmerje 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Prilagodi oknu</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zasukaj v levo</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zasukaj v desno</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Nazaj</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Upravljanje slike</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Moje priljubljene</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Razmerje 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Prilagodi oknu</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zasukaj v levo</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zasukaj v desno</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odstrani iz priljubljenih</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Dodaj med priljubljene</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Ne najdem slik</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Odpri sliko</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Slika ni bila najdena</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Nastavitve prosojnice</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Učinek</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Čas prikaza</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Bližnjice</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Prikaz</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Nov album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Časovnica</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Dodaj v album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Dodaj v nov album</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Izhod iz celozaslonskega načina</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celozaslonski način</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaprojekcija</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tiskanje</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstrani iz albuma</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Dodaj med priljubljene</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Odstrani iz priljubljenih</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Pokaži navigacijsko okno</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Skrij navigacijsko okno</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zasukaj v desno</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zasukaj v levo</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavi za ozadje</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informacije o sliki</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Odpri sliko</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Vse slike</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Nariši</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.6.orig.tar.xz: deepin-image-viewer-5.9.6/src/translations/deepin-image-viewer_sl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sl" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>Slika ni bila najdena</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Odpri sliko</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Prikazovanje slik</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celozaslonski način</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Izhod iz celozaslonskega načina</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Ekstrahiraj tekst</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diaprojekcija</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Zasukaj v desno</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Zasukaj v levo</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavi za ozadje</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Podatki o sliki</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Prejšnja</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Naslednja</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Približaj</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Oddalji</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Odpri</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Prikaži bližnjice</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Deepin pregledovalnik slik</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Pregledovalnik slik je orodje za prikazovanje slik z modernim vmesnikom in mehkim delovanjem.</translation>
    </message>
</context>
</TS>
